@@ -19,8 +19,12 @@ class Path:
     module = module_path
     repo = repo_path
     lyp = module_path / "klayout" / "sky130" / "layers.lyp"
-    libs = module_path / "libs"
+    libs = module_path / "sky130A"
     sparameters = module_path / "sparameters"
+
+    libs_tech = libs / "libs.tech"
+    libs_ref = libs / "libs.ref"
+    libs_ngspice = libs_tech / "ngspice"
     spice = module_path / "spice"
 
     libhd = libs / "sky130hd"
